# Contributing to Gateway Provisioners

Thank you for your interest in Gateway Provisioners! If you would like to contribute to the
project please first take a look at the
[Project Jupyter Contributor Documentation](https://jupyter.readthedocs.io/en/latest/contributing/content-contributor.html).

Gateway Provisioners is affiliated with the [Jupyter Server organization](https://github.com/jupyter-server) as
it is maintained by several team members. Please check out our
[team compass page](https://github.com/jupyter-server/team-compass#jupyter-server-team-compass) and try to attend
our weekly dev meeting as we have a common goal of making all Jupyter server-side applications better!

Prior to your contribution, we strongly recommend getting acquainted with Gateway Provisioners by checking
out the [System Architecture](system-architecture.md) and [Development Workflow](devinstall.md) pages.
